summaryrefslogtreecommitdiffstats
path: root/kunittest/runner.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kunittest/runner.cpp')
-rw-r--r--kunittest/runner.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kunittest/runner.cpp b/kunittest/runner.cpp
index f0eb5c4df..580d451b8 100644
--- a/kunittest/runner.cpp
+++ b/kunittest/runner.cpp
@@ -57,7 +57,7 @@ namespace KUnitTest
TQDir dir(folder, "kunittest_*.la");
// Add the folder to the "module" resource such that the KLibLoader can
// tqfind the modules in this folder.
KGlobal::dirs()->addResourceDir("module", folder);
kdDebug() << "Looking in folder: " << dir.absPath() << endl;
@@ -203,7 +203,7 @@ namespace KUnitTest
void Runner::runTest(const char *name)
{
- Tester *test = m_registry.tqfind(name);
+ Tester *test = m_registry.find(name);
if ( test == 0L ) return;
if ( s_debugCapturingEnabled )
@@ -57,7 +57,7 @@ namespace KUnitTest
TQDir dir(folder, "kunittest_*.la");
// Add the folder to the "module" resource such that the KLibLoader can
- // tqfind the modules in this folder.
+ // find the modules in this folder.
KGlobal::dirs()->addResourceDir("module", folder);
kdDebug() << "Looking in folder: " << dir.absPath() << endl;